@@ -59,38 +59,38 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qvertexblendanimation.h>
-#include <qanimationgroup.h>
-#include <qanimationaspect.h>
-#include <qkeyframeanimation.h>
-#include <qmorphinganimation.h>
 #include <qabstractanimation.h>
-#include <qabstractclipblendnode.h>
-#include <qabstractclipanimator.h>
-#include <qclipanimator.h>
-#include <qabstractanimationclip.h>
-#include <qlerpclipblend.h>
 #include <qanimationcontroller.h>
-#include <qblendedclipanimator.h>
+#include <qabstractclipanimator.h>
+#include <qabstractclipblendnode.h>
+#include <qmorphinganimation.h>
+#include <qlerpclipblend.h>
+#include <qkeyframeanimation.h>
+#include <qabstractanimationclip.h>
+#include <qvertexblendanimation.h>
 #include <qadditiveclipblend.h>
+#include <qclipanimator.h>
+#include <qanimationaspect.h>
 #include <qmorphtarget.h>
+#include <qblendedclipanimator.h>
+#include <qanimationgroup.h>
 // Conversion Includes - Primitive Types
 #include <QString>
 #include <QStringList>
-#include <qabstractitemmodel.h>
 #include <signalmanager.h>
+#include <qabstractitemmodel.h>
 
 // Conversion Includes - Container Types
-#include <QMap>
 #include <QList>
-#include <QMultiMap>
 #include <QLinkedList>
 #include <QVector>
-#include <QStack>
-#include <QQueue>
+#include <QSet>
 #include <QPair>
 #include <pysideqflags.h>
-#include <QSet>
+#include <QMap>
+#include <QStack>
+#include <QMultiMap>
+#include <QQueue>
 
 // Type indices
 #define SBK_QT3DANIMATION_IDX                                        0
@@ -98,19 +98,19 @@
 #define SBK_QT3DANIMATION_QANIMATIONGROUP_IDX                        10
 #define SBK_QT3DANIMATION_QABSTRACTANIMATION_IDX                     1
 #define SBK_QT3DANIMATION_QABSTRACTANIMATION_ANIMATIONTYPE_IDX       2
-#define SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX                  19
 #define SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                     17
 #define SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX              18
+#define SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX                  19
 #define SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                     13
 #define SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX          14
-#define SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_IDX                  4
-#define SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_LOOPS_IDX            5
-#define SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                          12
-#define SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX                   11
+#define SBK_QT3DANIMATION_QABSTRACTANIMATIONCLIP_IDX                 3
 #define SBK_QT3DANIMATION_QABSTRACTCLIPBLENDNODE_IDX                 6
 #define SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                         15
 #define SBK_QT3DANIMATION_QADDITIVECLIPBLEND_IDX                     7
-#define SBK_QT3DANIMATION_QABSTRACTANIMATIONCLIP_IDX                 3
+#define SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_IDX                  4
+#define SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_LOOPS_IDX            5
+#define SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX                   11
+#define SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                          12
 #define SBK_QT3DANIMATION_QANIMATIONASPECT_IDX                       8
 #define SBK_QT3DANIMATION_QMORPHTARGET_IDX                           16
 #define SBK_Qt3DAnimation_IDX_COUNT                                  20
@@ -129,9 +129,9 @@ extern SbkConverter** SbkPySide2_Qt3DAnimationTypeConverters;
 #define SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QABSTRACTANIMATIONPTR_IDX 4 // QVector<Qt3DAnimation::QAbstractAnimation* >
 #define SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QNODEPTR_IDX              5 // QVector<Qt3DCore::QNode* >
 #define SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QENTITYPTR_IDX            6 // QVector<Qt3DCore::QEntity* >
-#define SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QMORPHTARGETPTR_IDX  7 // QVector<Qt3DAnimation::QMorphTarget* >
-#define SBK_QT3DANIMATION_QVECTOR_FLOAT_IDX                          8 // const QVector<float > &
-#define SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QTRANSFORMPTR_IDX         9 // QVector<Qt3DCore::QTransform* >
+#define SBK_QT3DANIMATION_QVECTOR_FLOAT_IDX                          7 // QVector<float >
+#define SBK_QT3DANIMATION_QVECTOR_QT3DCORE_QTRANSFORMPTR_IDX         8 // QVector<Qt3DCore::QTransform* >
+#define SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QMORPHTARGETPTR_IDX  9 // QVector<Qt3DAnimation::QMorphTarget* >
 #define SBK_QT3DANIMATION_QLIST_QVARIANT_IDX                         10 // QList<QVariant >
 #define SBK_QT3DANIMATION_QLIST_QSTRING_IDX                          11 // QList<QString >
 #define SBK_QT3DANIMATION_QMAP_QSTRING_QVARIANT_IDX                  12 // QMap<QString,QVariant >
@@ -147,19 +147,19 @@ template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAnimationController >
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAnimationGroup >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONGROUP_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractAnimation::AnimationType >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTANIMATION_ANIMATIONTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTANIMATION_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QVertexBlendAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphingAnimation::Method >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphingAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QVertexBlendAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QKeyframeAnimation::RepeatMode >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QKeyframeAnimation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractClipAnimator::Loops >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_LOOPS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCLIPANIMATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QBlendedClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractAnimationClip >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTANIMATIONCLIP_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractClipBlendNode >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTCLIPBLENDNODE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QLerpClipBlend >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAdditiveClipBlend >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QADDITIVECLIPBLEND_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractAnimationClip >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTANIMATIONCLIP_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractClipAnimator::Loops >() { return SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_LOOPS_IDX]; }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAbstractClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QABSTRACTCLIPANIMATOR_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QBlendedClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QClipAnimator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCLIPANIMATOR_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QAnimationAspect >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONASPECT_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DAnimation::QMorphTarget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QMORPHTARGET_IDX]); }
 
