@@ -58,36 +58,36 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qsqlerror.h>
 #include <qsqldriver.h>
-#include <qsqlrelationaldelegate.h>
-#include <qtsqlglobal.h>
-#include <qsqldatabase.h>
 #include <qsqlquerymodel.h>
-#include <qsqlindex.h>
 #include <qsqlresult.h>
-#include <qsqltablemodel.h>
+#include <qtsqlglobal.h>
+#include <qsqlindex.h>
+#include <qsqlrelationaldelegate.h>
 #include <qsqlrelationaltablemodel.h>
+#include <qsqlquery.h>
+#include <qsqlerror.h>
+#include <qsqldatabase.h>
 #include <qsqlrecord.h>
 #include <qsqlfield.h>
-#include <qsqlquery.h>
+#include <qsqltablemodel.h>
 // Conversion Includes - Primitive Types
-#include <qabstractitemmodel.h>
-#include <QStringList>
 #include <QString>
+#include <qabstractitemmodel.h>
 #include <signalmanager.h>
+#include <QStringList>
 
 // Conversion Includes - Container Types
-#include <QMultiMap>
+#include <QVector>
 #include <QMap>
+#include <QMultiMap>
 #include <QPair>
 #include <pysideqflags.h>
 #include <QLinkedList>
-#include <QVector>
-#include <QList>
 #include <QStack>
-#include <QQueue>
+#include <QList>
 #include <QSet>
+#include <QQueue>
 
 // Type indices
 #define SBK_QSQL_IDX                                                 1
@@ -116,12 +116,12 @@
 #define SBK_QSQLDRIVER_IDENTIFIERTYPE_IDX                            10
 #define SBK_QSQLDRIVER_NOTIFICATIONSOURCE_IDX                        11
 #define SBK_QSQLDRIVER_DBMSTYPE_IDX                                  8
-#define SBK_QSQLRELATIONALDELEGATE_IDX                               24
 #define SBK_QSQLQUERYMODEL_IDX                                       21
 #define SBK_QSQLTABLEMODEL_IDX                                       30
 #define SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX                          31
 #define SBK_QSQLRELATIONALTABLEMODEL_IDX                             25
 #define SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX                    26
+#define SBK_QSQLRELATIONALDELEGATE_IDX                               24
 #define SBK_QtSql_IDX_COUNT                                          32
 
 // This variable stores all Python types exported by this module.
@@ -135,7 +135,7 @@ extern SbkConverter** SbkPySide2_QtSqlTypeConverters;
 #define SBK_QTSQL_QMAP_QSTRING_QVARIANT_IDX                          1 // QMap<QString,QVariant >
 #define SBK_QTSQL_QLIST_QOBJECTPTR_IDX                               2 // const QList<QObject* > &
 #define SBK_QTSQL_QLIST_QBYTEARRAY_IDX                               3 // QList<QByteArray >
-#define SBK_QTSQL_QVECTOR_INT_IDX                                    4 // QVector<int >
+#define SBK_QTSQL_QVECTOR_INT_IDX                                    4 // const QVector<int > &
 #define SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                           5 // const QHash<int,QByteArray > &
 #define SBK_QTSQL_QMAP_INT_QVARIANT_IDX                              6 // QMap<int,QVariant >
 #define SBK_QTSQL_QLIST_QPERSISTENTMODELINDEX_IDX                    7 // const QList<QPersistentModelIndex > &
@@ -174,12 +174,12 @@ template<> inline PyTypeObject* SbkType< ::QSqlDriver::IdentifierType >() { retu
 template<> inline PyTypeObject* SbkType< ::QSqlDriver::NotificationSource >() { return SbkPySide2_QtSqlTypes[SBK_QSQLDRIVER_NOTIFICATIONSOURCE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSqlDriver::DbmsType >() { return SbkPySide2_QtSqlTypes[SBK_QSQLDRIVER_DBMSTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSqlDriver >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLDRIVER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QSqlRelationalDelegate >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALDELEGATE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSqlQueryModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLQUERYMODEL_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSqlTableModel::EditStrategy >() { return SbkPySide2_QtSqlTypes[SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSqlTableModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLTABLEMODEL_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSqlRelationalTableModel::JoinMode >() { return SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSqlRelationalTableModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QSqlRelationalDelegate >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALDELEGATE_IDX]); }
 
 } // namespace Shiboken
 
